import { useState } from 'react';
import { useNavigate, Link } from 'react-router-dom';
import { toast } from 'sonner';
import { Cake, Lock, Mail } from 'lucide-react';

import { useAuthStore } from '@/lib/authStore';

import { Button } from '@/components/ui/button';
import { Input } from '@/components/ui/input';
import { Label } from '@/components/ui/label';

export default function Login() {
  const navigate = useNavigate();
  const { login } = useAuthStore();

  const [formData, setFormData] = useState({
    email: '',
    password: '',
  });

  const [errors, setErrors] = useState({});
  const [isSubmitting, setIsSubmitting] = useState(false);

  const handleChange = (e) => {
    const { name, value } = e.target;
    setFormData((prev) => ({
      ...prev,
      [name]: value,
    }));

    // Clear error when field is being edited
    if (errors[name]) {
      setErrors((prev) => ({
        ...prev,
        [name]: '',
      }));
    }
  };

  const validateForm = () => {
    const newErrors = {};

    if (!formData.email.trim()) {
      newErrors.email = 'Email is required';
    } else if (!/\S+@\S+\.\S+/.test(formData.email)) {
      newErrors.email = 'Email is invalid';
    }

    if (!formData.password) {
      newErrors.password = 'Password is required';
    } else if (formData.password.length < 6) {
      newErrors.password = 'Password must be at least 6 characters';
    }

    setErrors(newErrors);
    return Object.keys(newErrors).length === 0;
  };

  const handleSubmit = (e) => {
    e.preventDefault();

    if (!validateForm()) return;

    setIsSubmitting(true);

    setTimeout(() => {
      // Check if user exists in local storage
      const users = JSON.parse(localStorage.getItem('users') || '[]');
      const user = users.find((u) => u.email === formData.email);

      if (!user || user.password !== formData.password) {
        setErrors({
          auth: 'Invalid email or password',
        });
        setIsSubmitting(false);
        return;
      }

      // Login successful
      login({
        id: user.id,
        name: user.name,
        email: user.email,
      });

      toast({
        title: 'Login Successful',
        description: `Welcome back, ${user.name}!`,
      });

      setIsSubmitting(false);
      navigate('/');
    }, 1500);
  };

  return (
    <div className='container mx-auto px-4 py-8 md:py-12'>
      <div className='max-w-md mx-auto'>
        <div className='text-center mb-8'>
          <div className='mx-auto w-16 h-16 bg-pink-100 rounded-full flex items-center justify-center mb-4'>
            <Cake className='h-8 w-8 text-pink-500' />
          </div>
          <h1 className='text-3xl font-bold text-gray-800 mb-2'>
            Welcome Back
          </h1>
          <p className='text-gray-600'>
            Sign in to your Golden Crust Bakery account
          </p>
        </div>

        <div className='bg-white rounded-xl shadow-sm border overflow-hidden'>
          <div className='p-6'>
            {errors.auth && (
              <div className='mb-6 p-4 bg-red-50 border border-red-200 text-red-600 rounded-lg'>
                {errors.auth}
              </div>
            )}

            <form onSubmit={handleSubmit} className='space-y-6'>
              <div className='space-y-2'>
                <Label htmlFor='email'>Email Address</Label>
                <div className='relative'>
                  <Mail className='absolute left-3 top-1/2 transform -translate-y-1/2 text-gray-400 h-5 w-5' />
                  <Input
                    id='email'
                    name='email'
                    type='email'
                    value={formData.email}
                    onChange={handleChange}
                    className={`pl-10 rounded-lg ${
                      errors.email ? 'border-red-500' : 'border-gray-200'
                    }`}
                    placeholder='your.email@example.com'
                  />
                </div>
                {errors.email && (
                  <p className='text-red-500 text-sm'>{errors.email}</p>
                )}
              </div>

              <div className='space-y-2'>
                <div className='flex justify-between items-center'>
                  <Label htmlFor='password'>Password</Label>
                  <Link
                    to='#'
                    className='text-sm text-pink-600 hover:underline'
                  >
                    Forgot password?
                  </Link>
                </div>
                <div className='relative'>
                  <Lock className='absolute left-3 top-1/2 transform -translate-y-1/2 text-gray-400 h-5 w-5' />
                  <Input
                    id='password'
                    name='password'
                    type='password'
                    value={formData.password}
                    onChange={handleChange}
                    className={`pl-10 rounded-lg ${
                      errors.password ? 'border-red-500' : 'border-gray-200'
                    }`}
                    placeholder='********'
                  />
                </div>
                {errors.password && (
                  <p className='text-red-500 text-sm'>{errors.password}</p>
                )}
              </div>

              <Button
                type='submit'
                disabled={isSubmitting}
                className='w-full bg-pink-500 hover:bg-pink-600 text-white rounded-full py-6'
              >
                {isSubmitting ? 'Signing in...' : 'Sign In'}
              </Button>
            </form>

            <div className='mt-6 text-center'>
              <p className='text-gray-600'>
                Don't have an account?{' '}
                <Link
                  to='/register'
                  className='text-pink-600 hover:underline font-medium'
                >
                  Sign up
                </Link>
              </p>
            </div>
          </div>
        </div>

        <div className='mt-8 text-center'>
          <Button
            variant='ghost'
            onClick={() => navigate('/')}
            className='text-gray-600 hover:text-gray-800'
          >
            Return to Home
          </Button>
        </div>
      </div>
    </div>
  );
}
